@@ -20,7 +20,7 @@ def parse_args(subparsers):
         ),
     )
     add_msgdef_args(parser)
-    add_read_args(parser)
+    add_read_args(parser, ttl=10000)
     add_patterns_arg(parser, opt=True)
     parser.set_defaults(main=_main)
 
@@ -31,5 +31,5 @@ async def _main(args):
     await async_load_msgdefs(ebus, args)
     msgdefs = ebus.msgdefs.resolve(args.patterns.split(";"))
     print(f"Observing {msgdefs.summary()}")
-    async for msg in ebus.async_observe(msgdefs=msgdefs, defaultprio=9, setprio=args.prio, ttl=args.ttl):
+    async for msg in ebus.async_observe(msgdefs=msgdefs, defaultprio=args.defaultprio, ttl=args.ttl):
         print_msg(msg)
