@@ -108,11 +108,11 @@ class Connection:
         """
         await self._async_ensure_connection()
         line = await self._async_readline()
-        await self._async_checkline(line)
+        self._checkline(line)
         _LOGGER.debug(f"async_readline() = {line!r}")
         return line
 
-    async def async_readlines(self, infinite=False, check=False):
+    async def async_readlines(self, infinite=False, check=True):
         """
         Receive lines until an empty one.
 
@@ -124,7 +124,7 @@ class Connection:
         while True:
             line = await self._async_readline()
             if check:
-                await self._async_checkline(line)
+                self._checkline(line)
             _LOGGER.debug(f"readlines() = {line!r}")
             yield line
             if not line and not infinite:
@@ -151,11 +151,11 @@ class Connection:
             result = await task
         return result
 
-    async def _async_checkline(self, line):
+    @staticmethod
+    def _checkline(line):
+        if line == "ERR: shutdown":
+            raise EbusdShutdown()
         if line.startswith("ERR: "):
-            # consume everything until newline
-            while await self._async_readline():
-                pass
             raise CommandError(line.lstrip("ERR: "))
 
 
@@ -167,3 +167,14 @@ class CommandError(RuntimeError):
 class ConnectionTimeout(RuntimeError):
 
     """Connection Timeout."""
+
+    def __str__(self):
+        return "Connection Timeout."
+
+
+class EbusdShutdown(RuntimeError):
+
+    """Shutdown."""
+
+    def __str__(self):
+        return "EBUSD Shutdown."
