@@ -4,12 +4,12 @@ import collections
 import logging
 
 from .connection import CommandError, Connection
-from .const import OK
-from .msg import filter_msg
+from .const import AUTO, OK
+from .msg import BrokenMsg, filter_msg
 from .msgdecoder import MsgDecoder, UnknownMsgError
 from .msgdefdecoder import decode_msgdef
 from .msgdefs import MsgDefs
-from .util import repr_
+from .util import get_autoprio, repr_
 
 _LOGGER = logging.getLogger(__name__)
 _CMD_FINDMSGDEFS = "find -a -F type,circuit,name,fields"
@@ -118,21 +118,23 @@ class Ebus:
         for msgdef in sorted(msgdefs, key=lambda msgdef: (msgdef.circuit, msgdef.name)):
             self.msgdefs.add(msgdef)
 
-    async def async_read(self, msgdef, defaultprio=None, setprio=False, ttl=None):
+    async def async_read(self, msgdef, defaultprio=None, ttl=None):
         """
         Read Message.
 
         Raises:
             ValueError: on decoder error
         """
-        _LOGGER.info(f"read({msgdef!r}, defaultprio={defaultprio!r}, setprio={setprio!r}, ttl={ttl!r})")
-        prio = msgdef.prio or defaultprio if setprio else None
+        _LOGGER.info(f"read({msgdef!r}, defaultprio={defaultprio!r}, ttl={ttl!r})")
+        setprio = msgdef.setprio or defaultprio
+        if setprio == AUTO:
+            setprio = get_autoprio(msgdef)
         try:
             lines = tuple(
-                [line async for line in self._async_request("read", msgdef.name, c=msgdef.circuit, p=prio, m=ttl)]
+                [line async for line in self._async_request("read", msgdef.name, c=msgdef.circuit, p=setprio, m=ttl)]
             )
         except CommandError as exc:
-            _LOGGER.warning(f"{msgdef.ident}: {exc!r}")
+            return BrokenMsg(msgdef, str(exc))
         else:
             return self.msgdecoder.decode_value(msgdef, lines[0])
 
@@ -157,7 +159,7 @@ class Ebus:
         else:
             values = [str(fielddef.type_.encode(value)) for fielddef in msgdef.fields]
         # Write
-        async for _ in self._async_request("write", msgdef.name, ";".join(values), c=msgdef.circuit, check=True):
+        async for _ in self._async_request("write", msgdef.name, ";".join(values), c=msgdef.circuit):
             pass
 
     async def async_listen(self, msgdefs=None):
@@ -167,12 +169,11 @@ class Ebus:
             if line == "listen started":
                 continue
             msg = self._decode_line(line)
-            if msg is not None and msgdefs is not None:
-                msg = filter_msg(msg, msgdefs)
+            msg = filter_msg(msg, msgdefs)
             if msg:
                 yield msg
 
-    async def async_observe(self, msgdefs=None, defaultprio=None, setprio=False, ttl=None):
+    async def async_observe(self, msgdefs=None, defaultprio=None, ttl=None):
         """
         Observe.
 
@@ -180,30 +181,29 @@ class Ebus:
         Use `find` to get the latest data, if me missed any updates in the
         meantime and start listening
         """
-        _LOGGER.info(f"observe(msgdefs={msgdefs!r}, defaultprio={defaultprio!r}, setprio={setprio!r}, ttl={ttl!r})")
+        _LOGGER.info(f"observe(msgdefs={msgdefs!r}, defaultprio={defaultprio!r}, ttl={ttl!r})")
         msgdefs = msgdefs or self.msgdefs
         data = collections.defaultdict(lambda: None)
 
         # read all
         for msgdef in msgdefs:
             if msgdef.read:
-                msg = await self.async_read(msgdef, defaultprio=defaultprio, setprio=setprio, ttl=ttl)
-                if msg.valid:
-                    msg = filter_msg(msg, msgdefs)
-                if msg.valid:
-                    data[msgdef] = msg
-                yield msg
+                msg = await self.async_read(msgdef, defaultprio=defaultprio, ttl=ttl)
+                msg = filter_msg(msg, msgdefs)
+                if msg:
+                    if msg.valid:
+                        data[msgdef.ident] = msg
+                    yield msg
             elif msgdef.update:
-                data[msgdef] = None
+                data[msgdef.ident] = None
 
         # find new values (which got updated while we where reading)
         async for line in self._async_request("find -d"):
             msg = self._decode_line(line)
-            if msg:
-                msg = filter_msg(msg, msgdefs)
-            if msg and msg != data[msg.msgdef]:
+            msg = filter_msg(msg, msgdefs)
+            if msg and msg != data[msg.msgdef.ident]:
                 yield msg
-                data[msg.msgdef] = msg
+                data[msg.msgdef.ident] = msg
 
         # listen
         async for msg in self.async_listen(msgdefs=msgdefs):
@@ -239,18 +239,18 @@ class Ebus:
 
     async def async_cmd(self, cmd, infinite=False, check=False):
         """Send `cmd` to EBUSD and Receive Response."""
-        _LOGGER.info(f"cmd({cmd!r}, infinite={infinite!r}, check={check!r})")
+        _LOGGER.info(f"cmd({cmd!r}, infinite={infinite!r})")
         await self.connection.async_write(cmd)
         async for line in self.connection.async_readlines(infinite=infinite, check=check):
             yield line
 
-    async def _async_request(self, cmd, *args, infinite=False, check=False, **kwargs):
+    async def _async_request(self, cmd, *args, infinite=False, **kwargs):
         """Assemble request, send and readlines."""
         parts = [cmd]
         parts += [f"-{option} {value}" for option, value in kwargs.items() if value is not None]
         parts += [str(arg) for arg in args]
         await self.connection.async_write(" ".join(parts))
-        async for line in self.connection.async_readlines(infinite=infinite, check=check):
+        async for line in self.connection.async_readlines(infinite=infinite):
             yield line
 
     def _decode_line(self, line):
