@@ -6,7 +6,7 @@ from anytree import NodeMixin
 
 from .util import repr_
 
-_MsgDef = collections.namedtuple("_MsgDef", "circuit name read prio write update")
+_MsgDef = collections.namedtuple("_MsgDef", "circuit name read prio write update setprio")
 
 
 class MsgDef(_MsgDef, NodeMixin):
@@ -28,10 +28,10 @@ class MsgDef(_MsgDef, NodeMixin):
 
     __slots__ = tuple()
 
-    def __new__(cls, circuit, name, children, read=False, prio=None, write=False, update=False):
+    def __new__(cls, circuit, name, children, read=False, prio=None, write=False, update=False, setprio=None):
         if not read:
             prio = None
-        msgdef = _MsgDef.__new__(cls, circuit, name, read, prio, write, update)
+        msgdef = _MsgDef.__new__(cls, circuit, name, read, prio, write, update, setprio)
         if children:
             msgdef.children = children
         return msgdef
@@ -43,15 +43,27 @@ class MsgDef(_MsgDef, NodeMixin):
             ("prio", self.prio, None),
             ("write", self.write, False),
             ("update", self.update, False),
+            ("setprio", self.setprio, None),
         ]
         return repr_(self, args, kwargs)
 
     def __hash__(self):
-        return hash((self.circuit, self.name, self.children, self.read, self.prio, self.write, self.update))
+        return hash(
+            (self.circuit, self.name, self.children, self.read, self.prio, self.write, self.update, self.setprio)
+        )
 
     def __eq__(self, other):
         if self.__class__ is other.__class__:
-            return (self.circuit, self.name, self.children, self.read, self.prio, self.write, self.update) == (
+            return (
+                self.circuit,
+                self.name,
+                self.children,
+                self.read,
+                self.prio,
+                self.write,
+                self.update,
+                self.setprio,
+            ) == (
                 other.circuit,
                 other.name,
                 other.children,
@@ -59,6 +71,7 @@ class MsgDef(_MsgDef, NodeMixin):
                 other.prio,
                 other.write,
                 other.update,
+                other.setprio,
             )
         else:
             return NotImplemented
@@ -88,10 +101,11 @@ class MsgDef(_MsgDef, NodeMixin):
     def type_(self):
         """Message Type."""
         read = "r" if self.read else "-"
-        prio = f"{self.prio}" if self.prio else "-"
         write = "w" if self.write else "-"
         update = "u" if self.update else "-"
-        return "".join((read, prio, write, update))
+        setprio = str(self.setprio) if self.setprio else "-"
+        prio = str(self.prio) if self.prio else "-"
+        return "".join((read, write, update, setprio, prio))
 
     def join(self, msgdef):
         """Return Joined Message Definition."""
@@ -101,6 +115,7 @@ class MsgDef(_MsgDef, NodeMixin):
                 prio=self.prio or msgdef.prio,
                 write=self.write or msgdef.write,
                 update=self.update or msgdef.update,
+                setprio=self.setprio or msgdef.setprio,
             )
         else:
             return None
