@@ -3,6 +3,8 @@ import collections
 import re
 from fnmatch import fnmatchcase
 
+from .const import AUTO
+
 
 class MsgDefs:
 
@@ -31,7 +33,7 @@ class MsgDefs:
     '2 messages (2 read, 0 update, 0 write) with 7 fields'
     """
 
-    _re_resolve = re.compile(r"\A([^/#+]+)/([^/#+]+)(#(\d))?(/([^/#]*))?\Z")
+    _re_resolve = re.compile(r"\A([^/#+]+)/([^/#+]+)(#(\d|A))?(/([^/#]*))?\Z")
 
     def __init__(self):
         self.clear()
@@ -81,7 +83,7 @@ class MsgDefs:
     def _resolve(self, pattern):
         mat = self._re_resolve.fullmatch(pattern)
         if mat:
-            circuit, name, _, prio, _, fieldname = mat.groups()
+            circuit, name, _, setprio, _, fieldname = mat.groups()
             for msgdef in self.find(circuit, name):
                 if fieldname is None:
                     fields = msgdef.children
@@ -89,14 +91,11 @@ class MsgDefs:
                     fields = tuple(fielddef for fielddef in msgdef.children if fnmatchcase(fielddef.name, fieldname))
                 if not fields:
                     continue
-                if fields == msgdef.children and (prio is None or not msgdef.read):
+                if fields == msgdef.children and (setprio is None or not msgdef.read):
                     yield msgdef
                 else:
-                    if prio is None:
-                        prio = msgdef.prio
-                    else:
-                        prio = int(prio)
-                    yield msgdef.replace(children=fields, prio=prio)
+                    setprio = setprio if setprio in (AUTO, None) else int(setprio)
+                    yield msgdef.replace(children=fields, setprio=setprio)
         else:
             raise ValueError(f"Invalid pattern {pattern!r}")
 
