@@ -18,6 +18,20 @@ def repr_(obj, args=None, kwargs=None):
     return "%s(%s)" % (classname, ", ".join(args))
 
 
+def get_autoprio(msgdef):
+    """Calculate best priority."""
+    if msgdef.read:
+        # Prio is only available on read messages.
+        if msgdef.update or msgdef.write:
+            # we just want to ensure that we do not miss any value
+            # change, so just poll every second iteration.
+            return 2
+        else:
+            return 1
+    else:
+        return None
+
+
 class UnbufferedStream:
 
     """Unbuffered `stream`."""
